# coding: utf-8

"""
    Livoltek API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EnergyStore(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'battery_sn': 'object',
        'current_soc': 'object',
        'cycle_count': 'object',
        'battery_type_list': 'object',
        'history_map': 'EnergyStoreHistoryMap',
        'bmscapacity': 'object'
    }

    attribute_map = {
        'battery_sn': 'batterySn',
        'current_soc': 'currentSoc',
        'cycle_count': 'cycleCount',
        'battery_type_list': 'batteryTypeList',
        'history_map': 'historyMap',
        'bmscapacity': 'bmscapacity'
    }

    def __init__(self, battery_sn=None, current_soc=None, cycle_count=None, battery_type_list=None, history_map=None, bmscapacity=None):  # noqa: E501
        """EnergyStore - a model defined in Swagger"""  # noqa: E501
        self._battery_sn = None
        self._current_soc = None
        self._cycle_count = None
        self._battery_type_list = None
        self._history_map = None
        self._bmscapacity = None
        self.discriminator = None
        if battery_sn is not None:
            self.battery_sn = battery_sn
        if current_soc is not None:
            self.current_soc = current_soc
        if cycle_count is not None:
            self.cycle_count = cycle_count
        if battery_type_list is not None:
            self.battery_type_list = battery_type_list
        if history_map is not None:
            self.history_map = history_map
        if bmscapacity is not None:
            self.bmscapacity = bmscapacity

    @property
    def battery_sn(self):
        """Gets the battery_sn of this EnergyStore.  # noqa: E501

        Battery Serial Number  # noqa: E501

        :return: The battery_sn of this EnergyStore.  # noqa: E501
        :rtype: object
        """
        return self._battery_sn

    @battery_sn.setter
    def battery_sn(self, battery_sn):
        """Sets the battery_sn of this EnergyStore.

        Battery Serial Number  # noqa: E501

        :param battery_sn: The battery_sn of this EnergyStore.  # noqa: E501
        :type: object
        """

        self._battery_sn = battery_sn

    @property
    def current_soc(self):
        """Gets the current_soc of this EnergyStore.  # noqa: E501

        Battery State of Charge  # noqa: E501

        :return: The current_soc of this EnergyStore.  # noqa: E501
        :rtype: object
        """
        return self._current_soc

    @current_soc.setter
    def current_soc(self, current_soc):
        """Sets the current_soc of this EnergyStore.

        Battery State of Charge  # noqa: E501

        :param current_soc: The current_soc of this EnergyStore.  # noqa: E501
        :type: object
        """

        self._current_soc = current_soc

    @property
    def cycle_count(self):
        """Gets the cycle_count of this EnergyStore.  # noqa: E501

        Battery Cycle Count  # noqa: E501

        :return: The cycle_count of this EnergyStore.  # noqa: E501
        :rtype: object
        """
        return self._cycle_count

    @cycle_count.setter
    def cycle_count(self, cycle_count):
        """Sets the cycle_count of this EnergyStore.

        Battery Cycle Count  # noqa: E501

        :param cycle_count: The cycle_count of this EnergyStore.  # noqa: E501
        :type: object
        """

        self._cycle_count = cycle_count

    @property
    def battery_type_list(self):
        """Gets the battery_type_list of this EnergyStore.  # noqa: E501


        :return: The battery_type_list of this EnergyStore.  # noqa: E501
        :rtype: object
        """
        return self._battery_type_list

    @battery_type_list.setter
    def battery_type_list(self, battery_type_list):
        """Sets the battery_type_list of this EnergyStore.


        :param battery_type_list: The battery_type_list of this EnergyStore.  # noqa: E501
        :type: object
        """

        self._battery_type_list = battery_type_list

    @property
    def history_map(self):
        """Gets the history_map of this EnergyStore.  # noqa: E501

        History Map of Battery Usage  # noqa: E501

        :return: The history_map of this EnergyStore.  # noqa: E501
        :rtype: EnergyStoreHistoryMap
        """
        return self._history_map

    @history_map.setter
    def history_map(self, history_map):
        """Sets the history_map of this EnergyStore.

        History Map of Battery Usage  # noqa: E501

        :param history_map: The history_map of this EnergyStore.  # noqa: E501
        :type: EnergyStoreHistoryMap
        """

        self._history_map = history_map

    @property
    def bmscapacity(self):
        """Gets the bmscapacity of this EnergyStore.  # noqa: E501

        Battery Management System capacity (Ah)  # noqa: E501

        :return: The bmscapacity of this EnergyStore.  # noqa: E501
        :rtype: object
        """
        return self._bmscapacity

    @bmscapacity.setter
    def bmscapacity(self, bmscapacity):
        """Sets the bmscapacity of this EnergyStore.

        Battery Management System capacity (Ah)  # noqa: E501

        :param bmscapacity: The bmscapacity of this EnergyStore.  # noqa: E501
        :type: object
        """

        self._bmscapacity = bmscapacity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EnergyStore, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnergyStore):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Livoltek API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Site(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'power_station_id': 'object',
        'power_station_name': 'object',
        'country': 'object',
        'administrative_region': 'object',
        'power_station_type': 'object',
        'power_station_status': 'object',
        'pv_capacity': 'object',
        'registration_time': 'object',
        'update_time': 'object',
        'timezone': 'object'
    }

    attribute_map = {
        'power_station_id': 'powerStationId',
        'power_station_name': 'powerStationName',
        'country': 'country',
        'administrative_region': 'administrativeRegion',
        'power_station_type': 'powerStationType',
        'power_station_status': 'powerStationStatus',
        'pv_capacity': 'pvCapacity',
        'registration_time': 'registrationTime',
        'update_time': 'updateTime',
        'timezone': 'timezone'
    }

    def __init__(self, power_station_id=None, power_station_name=None, country=None, administrative_region=None, power_station_type=None, power_station_status=None, pv_capacity=None, registration_time=None, update_time=None, timezone=None):  # noqa: E501
        """Site - a model defined in Swagger"""  # noqa: E501
        self._power_station_id = None
        self._power_station_name = None
        self._country = None
        self._administrative_region = None
        self._power_station_type = None
        self._power_station_status = None
        self._pv_capacity = None
        self._registration_time = None
        self._update_time = None
        self._timezone = None
        self.discriminator = None
        if power_station_id is not None:
            self.power_station_id = power_station_id
        if power_station_name is not None:
            self.power_station_name = power_station_name
        if country is not None:
            self.country = country
        if administrative_region is not None:
            self.administrative_region = administrative_region
        if power_station_type is not None:
            self.power_station_type = power_station_type
        if power_station_status is not None:
            self.power_station_status = power_station_status
        if pv_capacity is not None:
            self.pv_capacity = pv_capacity
        if registration_time is not None:
            self.registration_time = registration_time
        if update_time is not None:
            self.update_time = update_time
        if timezone is not None:
            self.timezone = timezone

    @property
    def power_station_id(self):
        """Gets the power_station_id of this Site.  # noqa: E501

        Site ID  # noqa: E501

        :return: The power_station_id of this Site.  # noqa: E501
        :rtype: object
        """
        return self._power_station_id

    @power_station_id.setter
    def power_station_id(self, power_station_id):
        """Sets the power_station_id of this Site.

        Site ID  # noqa: E501

        :param power_station_id: The power_station_id of this Site.  # noqa: E501
        :type: object
        """

        self._power_station_id = power_station_id

    @property
    def power_station_name(self):
        """Gets the power_station_name of this Site.  # noqa: E501

        Site Name  # noqa: E501

        :return: The power_station_name of this Site.  # noqa: E501
        :rtype: object
        """
        return self._power_station_name

    @power_station_name.setter
    def power_station_name(self, power_station_name):
        """Sets the power_station_name of this Site.

        Site Name  # noqa: E501

        :param power_station_name: The power_station_name of this Site.  # noqa: E501
        :type: object
        """

        self._power_station_name = power_station_name

    @property
    def country(self):
        """Gets the country of this Site.  # noqa: E501

        Country/Region  # noqa: E501

        :return: The country of this Site.  # noqa: E501
        :rtype: object
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this Site.

        Country/Region  # noqa: E501

        :param country: The country of this Site.  # noqa: E501
        :type: object
        """

        self._country = country

    @property
    def administrative_region(self):
        """Gets the administrative_region of this Site.  # noqa: E501

        Administrative Division  # noqa: E501

        :return: The administrative_region of this Site.  # noqa: E501
        :rtype: object
        """
        return self._administrative_region

    @administrative_region.setter
    def administrative_region(self, administrative_region):
        """Sets the administrative_region of this Site.

        Administrative Division  # noqa: E501

        :param administrative_region: The administrative_region of this Site.  # noqa: E501
        :type: object
        """

        self._administrative_region = administrative_region

    @property
    def power_station_type(self):
        """Gets the power_station_type of this Site.  # noqa: E501

        Site Type  # noqa: E501

        :return: The power_station_type of this Site.  # noqa: E501
        :rtype: object
        """
        return self._power_station_type

    @power_station_type.setter
    def power_station_type(self, power_station_type):
        """Sets the power_station_type of this Site.

        Site Type  # noqa: E501

        :param power_station_type: The power_station_type of this Site.  # noqa: E501
        :type: object
        """

        self._power_station_type = power_station_type

    @property
    def power_station_status(self):
        """Gets the power_station_status of this Site.  # noqa: E501

        Site Communication status  # noqa: E501

        :return: The power_station_status of this Site.  # noqa: E501
        :rtype: object
        """
        return self._power_station_status

    @power_station_status.setter
    def power_station_status(self, power_station_status):
        """Sets the power_station_status of this Site.

        Site Communication status  # noqa: E501

        :param power_station_status: The power_station_status of this Site.  # noqa: E501
        :type: object
        """

        self._power_station_status = power_station_status

    @property
    def pv_capacity(self):
        """Gets the pv_capacity of this Site.  # noqa: E501

        PV Capacity  # noqa: E501

        :return: The pv_capacity of this Site.  # noqa: E501
        :rtype: object
        """
        return self._pv_capacity

    @pv_capacity.setter
    def pv_capacity(self, pv_capacity):
        """Sets the pv_capacity of this Site.

        PV Capacity  # noqa: E501

        :param pv_capacity: The pv_capacity of this Site.  # noqa: E501
        :type: object
        """

        self._pv_capacity = pv_capacity

    @property
    def registration_time(self):
        """Gets the registration_time of this Site.  # noqa: E501

        Lifetime generation  # noqa: E501

        :return: The registration_time of this Site.  # noqa: E501
        :rtype: object
        """
        return self._registration_time

    @registration_time.setter
    def registration_time(self, registration_time):
        """Sets the registration_time of this Site.

        Lifetime generation  # noqa: E501

        :param registration_time: The registration_time of this Site.  # noqa: E501
        :type: object
        """

        self._registration_time = registration_time

    @property
    def update_time(self):
        """Gets the update_time of this Site.  # noqa: E501

        Latest data update time  # noqa: E501

        :return: The update_time of this Site.  # noqa: E501
        :rtype: object
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this Site.

        Latest data update time  # noqa: E501

        :param update_time: The update_time of this Site.  # noqa: E501
        :type: object
        """

        self._update_time = update_time

    @property
    def timezone(self):
        """Gets the timezone of this Site.  # noqa: E501

        Time Zone  # noqa: E501

        :return: The timezone of this Site.  # noqa: E501
        :rtype: object
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """Sets the timezone of this Site.

        Time Zone  # noqa: E501

        :param timezone: The timezone of this Site.  # noqa: E501
        :type: object
        """

        self._timezone = timezone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Site, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Site):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Livoltek API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CurrentPowerFlow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'energy_status': 'object',
        'energy_power': 'object',
        'energy_soc': 'object',
        'pv_status': 'object',
        'pv_power': 'object',
        'power_grid_status': 'object',
        'power_grid_power': 'object',
        'load_status': 'object',
        'load_power': 'object',
        'charging_pile_status': 'object',
        'charging_pile_power': 'object',
        'timestamp': 'object'
    }

    attribute_map = {
        'energy_status': 'energyStatus',
        'energy_power': 'energyPower',
        'energy_soc': 'energySoc',
        'pv_status': 'pvStatus',
        'pv_power': 'pvPower',
        'power_grid_status': 'powerGridStatus',
        'power_grid_power': 'powerGridPower',
        'load_status': 'loadStatus',
        'load_power': 'loadPower',
        'charging_pile_status': 'chargingPileStatus',
        'charging_pile_power': 'chargingPilePower',
        'timestamp': 'timestamp'
    }

    def __init__(self, energy_status=None, energy_power=None, energy_soc=None, pv_status=None, pv_power=None, power_grid_status=None, power_grid_power=None, load_status=None, load_power=None, charging_pile_status=None, charging_pile_power=None, timestamp=None):  # noqa: E501
        """CurrentPowerFlow - a model defined in Swagger"""  # noqa: E501
        self._energy_status = None
        self._energy_power = None
        self._energy_soc = None
        self._pv_status = None
        self._pv_power = None
        self._power_grid_status = None
        self._power_grid_power = None
        self._load_status = None
        self._load_power = None
        self._charging_pile_status = None
        self._charging_pile_power = None
        self._timestamp = None
        self.discriminator = None
        if energy_status is not None:
            self.energy_status = energy_status
        if energy_power is not None:
            self.energy_power = energy_power
        if energy_soc is not None:
            self.energy_soc = energy_soc
        if pv_status is not None:
            self.pv_status = pv_status
        if pv_power is not None:
            self.pv_power = pv_power
        if power_grid_status is not None:
            self.power_grid_status = power_grid_status
        if power_grid_power is not None:
            self.power_grid_power = power_grid_power
        if load_status is not None:
            self.load_status = load_status
        if load_power is not None:
            self.load_power = load_power
        if charging_pile_status is not None:
            self.charging_pile_status = charging_pile_status
        if charging_pile_power is not None:
            self.charging_pile_power = charging_pile_power
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def energy_status(self):
        """Gets the energy_status of this CurrentPowerFlow.  # noqa: E501

        Battery working status  # noqa: E501

        :return: The energy_status of this CurrentPowerFlow.  # noqa: E501
        :rtype: object
        """
        return self._energy_status

    @energy_status.setter
    def energy_status(self, energy_status):
        """Sets the energy_status of this CurrentPowerFlow.

        Battery working status  # noqa: E501

        :param energy_status: The energy_status of this CurrentPowerFlow.  # noqa: E501
        :type: object
        """

        self._energy_status = energy_status

    @property
    def energy_power(self):
        """Gets the energy_power of this CurrentPowerFlow.  # noqa: E501

        Battery working power  # noqa: E501

        :return: The energy_power of this CurrentPowerFlow.  # noqa: E501
        :rtype: object
        """
        return self._energy_power

    @energy_power.setter
    def energy_power(self, energy_power):
        """Sets the energy_power of this CurrentPowerFlow.

        Battery working power  # noqa: E501

        :param energy_power: The energy_power of this CurrentPowerFlow.  # noqa: E501
        :type: object
        """

        self._energy_power = energy_power

    @property
    def energy_soc(self):
        """Gets the energy_soc of this CurrentPowerFlow.  # noqa: E501

        Battery SoC  # noqa: E501

        :return: The energy_soc of this CurrentPowerFlow.  # noqa: E501
        :rtype: object
        """
        return self._energy_soc

    @energy_soc.setter
    def energy_soc(self, energy_soc):
        """Sets the energy_soc of this CurrentPowerFlow.

        Battery SoC  # noqa: E501

        :param energy_soc: The energy_soc of this CurrentPowerFlow.  # noqa: E501
        :type: object
        """

        self._energy_soc = energy_soc

    @property
    def pv_status(self):
        """Gets the pv_status of this CurrentPowerFlow.  # noqa: E501

        PV working status  # noqa: E501

        :return: The pv_status of this CurrentPowerFlow.  # noqa: E501
        :rtype: object
        """
        return self._pv_status

    @pv_status.setter
    def pv_status(self, pv_status):
        """Sets the pv_status of this CurrentPowerFlow.

        PV working status  # noqa: E501

        :param pv_status: The pv_status of this CurrentPowerFlow.  # noqa: E501
        :type: object
        """

        self._pv_status = pv_status

    @property
    def pv_power(self):
        """Gets the pv_power of this CurrentPowerFlow.  # noqa: E501

        PV generating power  # noqa: E501

        :return: The pv_power of this CurrentPowerFlow.  # noqa: E501
        :rtype: object
        """
        return self._pv_power

    @pv_power.setter
    def pv_power(self, pv_power):
        """Sets the pv_power of this CurrentPowerFlow.

        PV generating power  # noqa: E501

        :param pv_power: The pv_power of this CurrentPowerFlow.  # noqa: E501
        :type: object
        """

        self._pv_power = pv_power

    @property
    def power_grid_status(self):
        """Gets the power_grid_status of this CurrentPowerFlow.  # noqa: E501

        Power grid working status  # noqa: E501

        :return: The power_grid_status of this CurrentPowerFlow.  # noqa: E501
        :rtype: object
        """
        return self._power_grid_status

    @power_grid_status.setter
    def power_grid_status(self, power_grid_status):
        """Sets the power_grid_status of this CurrentPowerFlow.

        Power grid working status  # noqa: E501

        :param power_grid_status: The power_grid_status of this CurrentPowerFlow.  # noqa: E501
        :type: object
        """

        self._power_grid_status = power_grid_status

    @property
    def power_grid_power(self):
        """Gets the power_grid_power of this CurrentPowerFlow.  # noqa: E501

        Power grid working power  # noqa: E501

        :return: The power_grid_power of this CurrentPowerFlow.  # noqa: E501
        :rtype: object
        """
        return self._power_grid_power

    @power_grid_power.setter
    def power_grid_power(self, power_grid_power):
        """Sets the power_grid_power of this CurrentPowerFlow.

        Power grid working power  # noqa: E501

        :param power_grid_power: The power_grid_power of this CurrentPowerFlow.  # noqa: E501
        :type: object
        """

        self._power_grid_power = power_grid_power

    @property
    def load_status(self):
        """Gets the load_status of this CurrentPowerFlow.  # noqa: E501

        Load working status  # noqa: E501

        :return: The load_status of this CurrentPowerFlow.  # noqa: E501
        :rtype: object
        """
        return self._load_status

    @load_status.setter
    def load_status(self, load_status):
        """Sets the load_status of this CurrentPowerFlow.

        Load working status  # noqa: E501

        :param load_status: The load_status of this CurrentPowerFlow.  # noqa: E501
        :type: object
        """

        self._load_status = load_status

    @property
    def load_power(self):
        """Gets the load_power of this CurrentPowerFlow.  # noqa: E501

        Load consuming power  # noqa: E501

        :return: The load_power of this CurrentPowerFlow.  # noqa: E501
        :rtype: object
        """
        return self._load_power

    @load_power.setter
    def load_power(self, load_power):
        """Sets the load_power of this CurrentPowerFlow.

        Load consuming power  # noqa: E501

        :param load_power: The load_power of this CurrentPowerFlow.  # noqa: E501
        :type: object
        """

        self._load_power = load_power

    @property
    def charging_pile_status(self):
        """Gets the charging_pile_status of this CurrentPowerFlow.  # noqa: E501

        EV charger working status  # noqa: E501

        :return: The charging_pile_status of this CurrentPowerFlow.  # noqa: E501
        :rtype: object
        """
        return self._charging_pile_status

    @charging_pile_status.setter
    def charging_pile_status(self, charging_pile_status):
        """Sets the charging_pile_status of this CurrentPowerFlow.

        EV charger working status  # noqa: E501

        :param charging_pile_status: The charging_pile_status of this CurrentPowerFlow.  # noqa: E501
        :type: object
        """

        self._charging_pile_status = charging_pile_status

    @property
    def charging_pile_power(self):
        """Gets the charging_pile_power of this CurrentPowerFlow.  # noqa: E501

        EV charger charging power  # noqa: E501

        :return: The charging_pile_power of this CurrentPowerFlow.  # noqa: E501
        :rtype: object
        """
        return self._charging_pile_power

    @charging_pile_power.setter
    def charging_pile_power(self, charging_pile_power):
        """Sets the charging_pile_power of this CurrentPowerFlow.

        EV charger charging power  # noqa: E501

        :param charging_pile_power: The charging_pile_power of this CurrentPowerFlow.  # noqa: E501
        :type: object
        """

        self._charging_pile_power = charging_pile_power

    @property
    def timestamp(self):
        """Gets the timestamp of this CurrentPowerFlow.  # noqa: E501

        Latest data update time  # noqa: E501

        :return: The timestamp of this CurrentPowerFlow.  # noqa: E501
        :rtype: object
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this CurrentPowerFlow.

        Latest data update time  # noqa: E501

        :param timestamp: The timestamp of this CurrentPowerFlow.  # noqa: E501
        :type: object
        """

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CurrentPowerFlow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CurrentPowerFlow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Livoltek API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SiteOverview(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'object',
        'online_device': 'object',
        'update_time': 'object',
        'current_power': 'object',
        'eout_daily': 'object',
        'eout_month': 'object',
        'eout_current_year': 'object',
        'e_total_to_grid': 'object'
    }

    attribute_map = {
        'name': 'name',
        'online_device': 'onlineDevice',
        'update_time': 'updateTime',
        'current_power': 'currentPower',
        'eout_daily': 'eoutDaily',
        'eout_month': 'eoutMonth',
        'eout_current_year': 'eoutCurrentYear',
        'e_total_to_grid': 'eTotalToGrid'
    }

    def __init__(self, name=None, online_device=None, update_time=None, current_power=None, eout_daily=None, eout_month=None, eout_current_year=None, e_total_to_grid=None):  # noqa: E501
        """SiteOverview - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._online_device = None
        self._update_time = None
        self._current_power = None
        self._eout_daily = None
        self._eout_month = None
        self._eout_current_year = None
        self._e_total_to_grid = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if online_device is not None:
            self.online_device = online_device
        if update_time is not None:
            self.update_time = update_time
        if current_power is not None:
            self.current_power = current_power
        if eout_daily is not None:
            self.eout_daily = eout_daily
        if eout_month is not None:
            self.eout_month = eout_month
        if eout_current_year is not None:
            self.eout_current_year = eout_current_year
        if e_total_to_grid is not None:
            self.e_total_to_grid = e_total_to_grid

    @property
    def name(self):
        """Gets the name of this SiteOverview.  # noqa: E501

        Site name  # noqa: E501

        :return: The name of this SiteOverview.  # noqa: E501
        :rtype: object
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SiteOverview.

        Site name  # noqa: E501

        :param name: The name of this SiteOverview.  # noqa: E501
        :type: object
        """

        self._name = name

    @property
    def online_device(self):
        """Gets the online_device of this SiteOverview.  # noqa: E501

        Amount of online equipment  # noqa: E501

        :return: The online_device of this SiteOverview.  # noqa: E501
        :rtype: object
        """
        return self._online_device

    @online_device.setter
    def online_device(self, online_device):
        """Sets the online_device of this SiteOverview.

        Amount of online equipment  # noqa: E501

        :param online_device: The online_device of this SiteOverview.  # noqa: E501
        :type: object
        """

        self._online_device = online_device

    @property
    def update_time(self):
        """Gets the update_time of this SiteOverview.  # noqa: E501

        Latest updated timestamp  # noqa: E501

        :return: The update_time of this SiteOverview.  # noqa: E501
        :rtype: object
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this SiteOverview.

        Latest updated timestamp  # noqa: E501

        :param update_time: The update_time of this SiteOverview.  # noqa: E501
        :type: object
        """

        self._update_time = update_time

    @property
    def current_power(self):
        """Gets the current_power of this SiteOverview.  # noqa: E501

        Real-time power  # noqa: E501

        :return: The current_power of this SiteOverview.  # noqa: E501
        :rtype: object
        """
        return self._current_power

    @current_power.setter
    def current_power(self, current_power):
        """Sets the current_power of this SiteOverview.

        Real-time power  # noqa: E501

        :param current_power: The current_power of this SiteOverview.  # noqa: E501
        :type: object
        """

        self._current_power = current_power

    @property
    def eout_daily(self):
        """Gets the eout_daily of this SiteOverview.  # noqa: E501

        Daily generation  # noqa: E501

        :return: The eout_daily of this SiteOverview.  # noqa: E501
        :rtype: object
        """
        return self._eout_daily

    @eout_daily.setter
    def eout_daily(self, eout_daily):
        """Sets the eout_daily of this SiteOverview.

        Daily generation  # noqa: E501

        :param eout_daily: The eout_daily of this SiteOverview.  # noqa: E501
        :type: object
        """

        self._eout_daily = eout_daily

    @property
    def eout_month(self):
        """Gets the eout_month of this SiteOverview.  # noqa: E501

        Monthly generation  # noqa: E501

        :return: The eout_month of this SiteOverview.  # noqa: E501
        :rtype: object
        """
        return self._eout_month

    @eout_month.setter
    def eout_month(self, eout_month):
        """Sets the eout_month of this SiteOverview.

        Monthly generation  # noqa: E501

        :param eout_month: The eout_month of this SiteOverview.  # noqa: E501
        :type: object
        """

        self._eout_month = eout_month

    @property
    def eout_current_year(self):
        """Gets the eout_current_year of this SiteOverview.  # noqa: E501

        Annual generation  # noqa: E501

        :return: The eout_current_year of this SiteOverview.  # noqa: E501
        :rtype: object
        """
        return self._eout_current_year

    @eout_current_year.setter
    def eout_current_year(self, eout_current_year):
        """Sets the eout_current_year of this SiteOverview.

        Annual generation  # noqa: E501

        :param eout_current_year: The eout_current_year of this SiteOverview.  # noqa: E501
        :type: object
        """

        self._eout_current_year = eout_current_year

    @property
    def e_total_to_grid(self):
        """Gets the e_total_to_grid of this SiteOverview.  # noqa: E501

        Lifetime generation  # noqa: E501

        :return: The e_total_to_grid of this SiteOverview.  # noqa: E501
        :rtype: object
        """
        return self._e_total_to_grid

    @e_total_to_grid.setter
    def e_total_to_grid(self, e_total_to_grid):
        """Sets the e_total_to_grid of this SiteOverview.

        Lifetime generation  # noqa: E501

        :param e_total_to_grid: The e_total_to_grid of this SiteOverview.  # noqa: E501
        :type: object
        """

        self._e_total_to_grid = e_total_to_grid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SiteOverview, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SiteOverview):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Livoltek API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pylivoltek
from pylivoltek.api.default_api import DefaultApi  # noqa: E501
from pylivoltek.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_hess_api_device_device_id_real_electricity_get(self):
        """Test case for hess_api_device_device_id_real_electricity_get

        Device Generation or Consumption  # noqa: E501
        """
        pass

    def test_hess_api_device_site_id_list_get(self):
        """Test case for hess_api_device_site_id_list_get

        Device List  # noqa: E501
        """
        pass

    def test_hess_api_login_post(self):
        """Test case for hess_api_login_post

        API User Login and Get Token  # noqa: E501
        """
        pass

    def test_hess_api_site_site_id_cur_powerflow_get(self):
        """Test case for hess_api_site_site_id_cur_powerflow_get

        Current Power Flow  # noqa: E501
        """
        pass

    def test_hess_api_site_site_id_overview_get(self):
        """Test case for hess_api_site_site_id_overview_get

        Site Generation Overview  # noqa: E501
        """
        pass

    def test_hess_api_user_sites_list_get(self):
        """Test case for hess_api_user_sites_list_get

        Site List  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Livoltek API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from pylivoltek.models.api_login_body import ApiLoginBody
from pylivoltek.models.api_response import ApiResponse
from pylivoltek.models.current_power_flow import CurrentPowerFlow
from pylivoltek.models.device import Device
from pylivoltek.models.device_details import DeviceDetails
from pylivoltek.models.device_list import DeviceList
from pylivoltek.models.energy_store import EnergyStore
from pylivoltek.models.energy_store_battery_type import EnergyStoreBatteryType
from pylivoltek.models.energy_store_history_map import EnergyStoreHistoryMap
from pylivoltek.models.energy_store_history_map_item import EnergyStoreHistoryMapItem
from pylivoltek.models.grid_import_export import GridImportExport
from pylivoltek.models.grid_import_export_api_response import GridImportExportApiResponse
from pylivoltek.models.grid_import_export_list import GridImportExportList
from pylivoltek.models.inline_response200 import InlineResponse200
from pylivoltek.models.inline_response2001 import InlineResponse2001
from pylivoltek.models.inline_response2001_data import InlineResponse2001Data
from pylivoltek.models.inline_response2002 import InlineResponse2002
from pylivoltek.models.inline_response2003 import InlineResponse2003
from pylivoltek.models.inline_response2004 import InlineResponse2004
from pylivoltek.models.inline_response2005 import InlineResponse2005
from pylivoltek.models.inline_response2006 import InlineResponse2006
from pylivoltek.models.inline_response2007 import InlineResponse2007
from pylivoltek.models.site import Site
from pylivoltek.models.site_list import SiteList
from pylivoltek.models.site_overview import SiteOverview
from pylivoltek.models.solar_generation import SolarGeneration
from pylivoltek.models.solar_generation_api_response import SolarGenerationApiResponse
from pylivoltek.models.solar_generationt_list import SolarGenerationtList



# coding: utf-8

"""
    Livoltek API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EnergyStoreHistoryMapItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'energy_power': 'object',
        'energy_soc': 'object',
        'energy_volage': 'object',
        'charge': 'object',
        'discharge': 'object',
        'time': 'object'
    }

    attribute_map = {
        'energy_power': 'energyPower',
        'energy_soc': 'energySoc',
        'energy_volage': 'energyVolage',
        'charge': 'charge',
        'discharge': 'discharge',
        'time': 'time'
    }

    def __init__(self, energy_power=None, energy_soc=None, energy_volage=None, charge=None, discharge=None, time=None):  # noqa: E501
        """EnergyStoreHistoryMapItem - a model defined in Swagger"""  # noqa: E501
        self._energy_power = None
        self._energy_soc = None
        self._energy_volage = None
        self._charge = None
        self._discharge = None
        self._time = None
        self.discriminator = None
        if energy_power is not None:
            self.energy_power = energy_power
        if energy_soc is not None:
            self.energy_soc = energy_soc
        if energy_volage is not None:
            self.energy_volage = energy_volage
        if charge is not None:
            self.charge = charge
        if discharge is not None:
            self.discharge = discharge
        if time is not None:
            self.time = time

    @property
    def energy_power(self):
        """Gets the energy_power of this EnergyStoreHistoryMapItem.  # noqa: E501

        Battery power  # noqa: E501

        :return: The energy_power of this EnergyStoreHistoryMapItem.  # noqa: E501
        :rtype: object
        """
        return self._energy_power

    @energy_power.setter
    def energy_power(self, energy_power):
        """Sets the energy_power of this EnergyStoreHistoryMapItem.

        Battery power  # noqa: E501

        :param energy_power: The energy_power of this EnergyStoreHistoryMapItem.  # noqa: E501
        :type: object
        """

        self._energy_power = energy_power

    @property
    def energy_soc(self):
        """Gets the energy_soc of this EnergyStoreHistoryMapItem.  # noqa: E501

        Battery SoC  # noqa: E501

        :return: The energy_soc of this EnergyStoreHistoryMapItem.  # noqa: E501
        :rtype: object
        """
        return self._energy_soc

    @energy_soc.setter
    def energy_soc(self, energy_soc):
        """Sets the energy_soc of this EnergyStoreHistoryMapItem.

        Battery SoC  # noqa: E501

        :param energy_soc: The energy_soc of this EnergyStoreHistoryMapItem.  # noqa: E501
        :type: object
        """

        self._energy_soc = energy_soc

    @property
    def energy_volage(self):
        """Gets the energy_volage of this EnergyStoreHistoryMapItem.  # noqa: E501

        Battery voltage  # noqa: E501

        :return: The energy_volage of this EnergyStoreHistoryMapItem.  # noqa: E501
        :rtype: object
        """
        return self._energy_volage

    @energy_volage.setter
    def energy_volage(self, energy_volage):
        """Sets the energy_volage of this EnergyStoreHistoryMapItem.

        Battery voltage  # noqa: E501

        :param energy_volage: The energy_volage of this EnergyStoreHistoryMapItem.  # noqa: E501
        :type: object
        """

        self._energy_volage = energy_volage

    @property
    def charge(self):
        """Gets the charge of this EnergyStoreHistoryMapItem.  # noqa: E501

        Charging energy  # noqa: E501

        :return: The charge of this EnergyStoreHistoryMapItem.  # noqa: E501
        :rtype: object
        """
        return self._charge

    @charge.setter
    def charge(self, charge):
        """Sets the charge of this EnergyStoreHistoryMapItem.

        Charging energy  # noqa: E501

        :param charge: The charge of this EnergyStoreHistoryMapItem.  # noqa: E501
        :type: object
        """

        self._charge = charge

    @property
    def discharge(self):
        """Gets the discharge of this EnergyStoreHistoryMapItem.  # noqa: E501

        Discharging energy  # noqa: E501

        :return: The discharge of this EnergyStoreHistoryMapItem.  # noqa: E501
        :rtype: object
        """
        return self._discharge

    @discharge.setter
    def discharge(self, discharge):
        """Sets the discharge of this EnergyStoreHistoryMapItem.

        Discharging energy  # noqa: E501

        :param discharge: The discharge of this EnergyStoreHistoryMapItem.  # noqa: E501
        :type: object
        """

        self._discharge = discharge

    @property
    def time(self):
        """Gets the time of this EnergyStoreHistoryMapItem.  # noqa: E501

        Timestamp (ms)  # noqa: E501

        :return: The time of this EnergyStoreHistoryMapItem.  # noqa: E501
        :rtype: object
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this EnergyStoreHistoryMapItem.

        Timestamp (ms)  # noqa: E501

        :param time: The time of this EnergyStoreHistoryMapItem.  # noqa: E501
        :type: object
        """

        self._time = time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EnergyStoreHistoryMapItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnergyStoreHistoryMapItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Livoltek API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pylivoltek.api_client import ApiClient


class DefaultApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_device_details(self, user_token, site_id, serial_number, **kwargs):  # noqa: E501
        """Device Details  # noqa: E501

        Query the equipment information of the specified device to obtain the device model, SN, working condition (offline, normal, fault, etc.) and its update time, firmware version, device type and manufacturer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_details(user_token, site_id, serial_number, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object site_id: Site ID (required)
        :param object serial_number: Site ID (required)
        :param object user_type: User Type
        :return: InlineResponse2005
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_device_details_with_http_info(user_token, site_id, serial_number, **kwargs)  # noqa: E501
        else:
            (data) = self.get_device_details_with_http_info(user_token, site_id, serial_number, **kwargs)  # noqa: E501
            return data

    def get_device_details_with_http_info(self, user_token, site_id, serial_number, **kwargs):  # noqa: E501
        """Device Details  # noqa: E501

        Query the equipment information of the specified device to obtain the device model, SN, working condition (offline, normal, fault, etc.) and its update time, firmware version, device type and manufacturer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_details_with_http_info(user_token, site_id, serial_number, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object site_id: Site ID (required)
        :param object serial_number: Site ID (required)
        :param object user_type: User Type
        :return: InlineResponse2005
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_token', 'site_id', 'serial_number', 'user_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_device_details" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_token' is set
        if ('user_token' not in params or
                params['user_token'] is None):
            raise ValueError("Missing the required parameter `user_token` when calling `get_device_details`")  # noqa: E501
        # verify the required parameter 'site_id' is set
        if ('site_id' not in params or
                params['site_id'] is None):
            raise ValueError("Missing the required parameter `site_id` when calling `get_device_details`")  # noqa: E501
        # verify the required parameter 'serial_number' is set
        if ('serial_number' not in params or
                params['serial_number'] is None):
            raise ValueError("Missing the required parameter `serial_number` when calling `get_device_details`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'site_id' in params:
            path_params['siteId'] = params['site_id']  # noqa: E501
        if 'serial_number' in params:
            path_params['serialNumber'] = params['serial_number']  # noqa: E501

        query_params = []
        if 'user_token' in params:
            query_params.append(('userToken', params['user_token']))  # noqa: E501
        if 'user_type' in params:
            query_params.append(('userType', params['user_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/hess/api/device/{siteId}/{serialNumber}/details', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2005',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_energy_storage(self, user_token, site_id, **kwargs):  # noqa: E501
        """Energy Storage Information  # noqa: E501

        Query the information of the energy storage battery within the specified site to obtain the BAT capacity, BMS SN, current SOC/voltage, battery type, and power / voltage / SOC in recent 7 days, and daily charge and discharge capacity in the last 7 days.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_energy_storage(user_token, site_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object site_id: Site ID (required)
        :param object user_type: User Type
        :return: InlineResponse2007
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_energy_storage_with_http_info(user_token, site_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_energy_storage_with_http_info(user_token, site_id, **kwargs)  # noqa: E501
            return data

    def get_energy_storage_with_http_info(self, user_token, site_id, **kwargs):  # noqa: E501
        """Energy Storage Information  # noqa: E501

        Query the information of the energy storage battery within the specified site to obtain the BAT capacity, BMS SN, current SOC/voltage, battery type, and power / voltage / SOC in recent 7 days, and daily charge and discharge capacity in the last 7 days.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_energy_storage_with_http_info(user_token, site_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object site_id: Site ID (required)
        :param object user_type: User Type
        :return: InlineResponse2007
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_token', 'site_id', 'user_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_energy_storage" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_token' is set
        if ('user_token' not in params or
                params['user_token'] is None):
            raise ValueError("Missing the required parameter `user_token` when calling `get_energy_storage`")  # noqa: E501
        # verify the required parameter 'site_id' is set
        if ('site_id' not in params or
                params['site_id'] is None):
            raise ValueError("Missing the required parameter `site_id` when calling `get_energy_storage`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'site_id' in params:
            path_params['siteId'] = params['site_id']  # noqa: E501

        query_params = []
        if 'user_token' in params:
            query_params.append(('userToken', params['user_token']))  # noqa: E501
        if 'user_type' in params:
            query_params.append(('userType', params['user_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/hess/api/site/{siteId}/ESS', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2007',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_recent_energy_import_export(self, user_token, site_id, **kwargs):  # noqa: E501
        """Get grid import/export history for the last 3 days.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_recent_energy_import_export(user_token, site_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object site_id: Site ID (required)
        :param object user_type: User Type
        :return: GridImportExportApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_recent_energy_import_export_with_http_info(user_token, site_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_recent_energy_import_export_with_http_info(user_token, site_id, **kwargs)  # noqa: E501
            return data

    def get_recent_energy_import_export_with_http_info(self, user_token, site_id, **kwargs):  # noqa: E501
        """Get grid import/export history for the last 3 days.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_recent_energy_import_export_with_http_info(user_token, site_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object site_id: Site ID (required)
        :param object user_type: User Type
        :return: GridImportExportApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_token', 'site_id', 'user_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_recent_energy_import_export" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_token' is set
        if ('user_token' not in params or
                params['user_token'] is None):
            raise ValueError("Missing the required parameter `user_token` when calling `get_recent_energy_import_export`")  # noqa: E501
        # verify the required parameter 'site_id' is set
        if ('site_id' not in params or
                params['site_id'] is None):
            raise ValueError("Missing the required parameter `site_id` when calling `get_recent_energy_import_export`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'site_id' in params:
            path_params['siteId'] = params['site_id']  # noqa: E501

        query_params = []
        if 'user_token' in params:
            query_params.append(('userToken', params['user_token']))  # noqa: E501
        if 'user_type' in params:
            query_params.append(('userType', params['user_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/hess/api/site/{siteId}/reissueUtilityEnergy', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GridImportExportApiResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_recent_solar_generated_energy(self, user_token, site_id, **kwargs):  # noqa: E501
        """Get solar generation history for the last 3 days.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_recent_solar_generated_energy(user_token, site_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object site_id: Site ID (required)
        :param object user_type: User Type
        :return: SolarGenerationApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_recent_solar_generated_energy_with_http_info(user_token, site_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_recent_solar_generated_energy_with_http_info(user_token, site_id, **kwargs)  # noqa: E501
            return data

    def get_recent_solar_generated_energy_with_http_info(self, user_token, site_id, **kwargs):  # noqa: E501
        """Get solar generation history for the last 3 days.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_recent_solar_generated_energy_with_http_info(user_token, site_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object site_id: Site ID (required)
        :param object user_type: User Type
        :return: SolarGenerationApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_token', 'site_id', 'user_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_recent_solar_generated_energy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_token' is set
        if ('user_token' not in params or
                params['user_token'] is None):
            raise ValueError("Missing the required parameter `user_token` when calling `get_recent_solar_generated_energy`")  # noqa: E501
        # verify the required parameter 'site_id' is set
        if ('site_id' not in params or
                params['site_id'] is None):
            raise ValueError("Missing the required parameter `site_id` when calling `get_recent_solar_generated_energy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'site_id' in params:
            path_params['siteId'] = params['site_id']  # noqa: E501

        query_params = []
        if 'user_token' in params:
            query_params.append(('userToken', params['user_token']))  # noqa: E501
        if 'user_type' in params:
            query_params.append(('userType', params['user_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/hess/api/site/{siteId}/reissueSolarEnergy', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SolarGenerationApiResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def hess_api_device_device_id_real_electricity_get(self, user_token, device_id, **kwargs):  # noqa: E501
        """Device Generation or Consumption  # noqa: E501

        Return device lifetime generation or consumption  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.hess_api_device_device_id_real_electricity_get(user_token, device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object device_id: Device ID (required)
        :param object user_type: User Type
        :return: InlineResponse2003
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.hess_api_device_device_id_real_electricity_get_with_http_info(user_token, device_id, **kwargs)  # noqa: E501
        else:
            (data) = self.hess_api_device_device_id_real_electricity_get_with_http_info(user_token, device_id, **kwargs)  # noqa: E501
            return data

    def hess_api_device_device_id_real_electricity_get_with_http_info(self, user_token, device_id, **kwargs):  # noqa: E501
        """Device Generation or Consumption  # noqa: E501

        Return device lifetime generation or consumption  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.hess_api_device_device_id_real_electricity_get_with_http_info(user_token, device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object device_id: Device ID (required)
        :param object user_type: User Type
        :return: InlineResponse2003
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_token', 'device_id', 'user_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hess_api_device_device_id_real_electricity_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_token' is set
        if ('user_token' not in params or
                params['user_token'] is None):
            raise ValueError("Missing the required parameter `user_token` when calling `hess_api_device_device_id_real_electricity_get`")  # noqa: E501
        # verify the required parameter 'device_id' is set
        if ('device_id' not in params or
                params['device_id'] is None):
            raise ValueError("Missing the required parameter `device_id` when calling `hess_api_device_device_id_real_electricity_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'device_id' in params:
            path_params['deviceId'] = params['device_id']  # noqa: E501

        query_params = []
        if 'user_token' in params:
            query_params.append(('userToken', params['user_token']))  # noqa: E501
        if 'user_type' in params:
            query_params.append(('userType', params['user_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/hess/api/device/{deviceId}/realElectricity', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2003',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def hess_api_device_site_id_list_get(self, user_token, site_id, page, size, **kwargs):  # noqa: E501
        """Device List  # noqa: E501

        Return the number of equipment in the specified site, equipment ID, equipment type (inverter, charging pile, electricity meter, etc.), equipment model, equipment SN and equipment manufacturer  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.hess_api_device_site_id_list_get(user_token, site_id, page, size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object site_id: Site ID (required)
        :param object page: The first device index to be returned in the results, default=1 (required)
        :param object size: Pagesize of each page (required)
        :param object user_type: User Type
        :return: InlineResponse2006
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.hess_api_device_site_id_list_get_with_http_info(user_token, site_id, page, size, **kwargs)  # noqa: E501
        else:
            (data) = self.hess_api_device_site_id_list_get_with_http_info(user_token, site_id, page, size, **kwargs)  # noqa: E501
            return data

    def hess_api_device_site_id_list_get_with_http_info(self, user_token, site_id, page, size, **kwargs):  # noqa: E501
        """Device List  # noqa: E501

        Return the number of equipment in the specified site, equipment ID, equipment type (inverter, charging pile, electricity meter, etc.), equipment model, equipment SN and equipment manufacturer  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.hess_api_device_site_id_list_get_with_http_info(user_token, site_id, page, size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object site_id: Site ID (required)
        :param object page: The first device index to be returned in the results, default=1 (required)
        :param object size: Pagesize of each page (required)
        :param object user_type: User Type
        :return: InlineResponse2006
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_token', 'site_id', 'page', 'size', 'user_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hess_api_device_site_id_list_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_token' is set
        if ('user_token' not in params or
                params['user_token'] is None):
            raise ValueError("Missing the required parameter `user_token` when calling `hess_api_device_site_id_list_get`")  # noqa: E501
        # verify the required parameter 'site_id' is set
        if ('site_id' not in params or
                params['site_id'] is None):
            raise ValueError("Missing the required parameter `site_id` when calling `hess_api_device_site_id_list_get`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `hess_api_device_site_id_list_get`")  # noqa: E501
        # verify the required parameter 'size' is set
        if ('size' not in params or
                params['size'] is None):
            raise ValueError("Missing the required parameter `size` when calling `hess_api_device_site_id_list_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'site_id' in params:
            path_params['siteId'] = params['site_id']  # noqa: E501

        query_params = []
        if 'user_token' in params:
            query_params.append(('userToken', params['user_token']))  # noqa: E501
        if 'user_type' in params:
            query_params.append(('userType', params['user_type']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'size' in params:
            query_params.append(('size', params['size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/hess/api/device/{siteId}/list', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2006',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def hess_api_login_post(self, body, **kwargs):  # noqa: E501
        """API User Login and Get Token  # noqa: E501

        Get api user token and verify whether the API caller has permission  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.hess_api_login_post(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ApiLoginBody body: (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.hess_api_login_post_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.hess_api_login_post_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def hess_api_login_post_with_http_info(self, body, **kwargs):  # noqa: E501
        """API User Login and Get Token  # noqa: E501

        Get api user token and verify whether the API caller has permission  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.hess_api_login_post_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ApiLoginBody body: (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hess_api_login_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `hess_api_login_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/hess/api/login', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def hess_api_site_site_id_cur_powerflow_get(self, user_token, site_id, **kwargs):  # noqa: E501
        """Current Power Flow  # noqa: E501

        Query the current energy flow of the specified power station to obtain the last update time, status of each system type, parameter unit (W) and value  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.hess_api_site_site_id_cur_powerflow_get(user_token, site_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object site_id: Site ID (required)
        :param object user_type: User Type
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.hess_api_site_site_id_cur_powerflow_get_with_http_info(user_token, site_id, **kwargs)  # noqa: E501
        else:
            (data) = self.hess_api_site_site_id_cur_powerflow_get_with_http_info(user_token, site_id, **kwargs)  # noqa: E501
            return data

    def hess_api_site_site_id_cur_powerflow_get_with_http_info(self, user_token, site_id, **kwargs):  # noqa: E501
        """Current Power Flow  # noqa: E501

        Query the current energy flow of the specified power station to obtain the last update time, status of each system type, parameter unit (W) and value  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.hess_api_site_site_id_cur_powerflow_get_with_http_info(user_token, site_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object site_id: Site ID (required)
        :param object user_type: User Type
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_token', 'site_id', 'user_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hess_api_site_site_id_cur_powerflow_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_token' is set
        if ('user_token' not in params or
                params['user_token'] is None):
            raise ValueError("Missing the required parameter `user_token` when calling `hess_api_site_site_id_cur_powerflow_get`")  # noqa: E501
        # verify the required parameter 'site_id' is set
        if ('site_id' not in params or
                params['site_id'] is None):
            raise ValueError("Missing the required parameter `site_id` when calling `hess_api_site_site_id_cur_powerflow_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'site_id' in params:
            path_params['siteId'] = params['site_id']  # noqa: E501

        query_params = []
        if 'user_token' in params:
            query_params.append(('userToken', params['user_token']))  # noqa: E501
        if 'user_type' in params:
            query_params.append(('userType', params['user_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/hess/api/site/{siteId}/curPowerflow', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def hess_api_site_site_id_overview_get(self, user_token, site_id, **kwargs):  # noqa: E501
        """Site Generation Overview  # noqa: E501

        Return generation review of selected site, including site name，amount of online equipment, latest updated timestamp, power, daily generation, monthly generation, yearly generation, lifetime generation  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.hess_api_site_site_id_overview_get(user_token, site_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object site_id: Site ID (required)
        :param object user_type: User Type
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.hess_api_site_site_id_overview_get_with_http_info(user_token, site_id, **kwargs)  # noqa: E501
        else:
            (data) = self.hess_api_site_site_id_overview_get_with_http_info(user_token, site_id, **kwargs)  # noqa: E501
            return data

    def hess_api_site_site_id_overview_get_with_http_info(self, user_token, site_id, **kwargs):  # noqa: E501
        """Site Generation Overview  # noqa: E501

        Return generation review of selected site, including site name，amount of online equipment, latest updated timestamp, power, daily generation, monthly generation, yearly generation, lifetime generation  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.hess_api_site_site_id_overview_get_with_http_info(user_token, site_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object site_id: Site ID (required)
        :param object user_type: User Type
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_token', 'site_id', 'user_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hess_api_site_site_id_overview_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_token' is set
        if ('user_token' not in params or
                params['user_token'] is None):
            raise ValueError("Missing the required parameter `user_token` when calling `hess_api_site_site_id_overview_get`")  # noqa: E501
        # verify the required parameter 'site_id' is set
        if ('site_id' not in params or
                params['site_id'] is None):
            raise ValueError("Missing the required parameter `site_id` when calling `hess_api_site_site_id_overview_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'site_id' in params:
            path_params['siteId'] = params['site_id']  # noqa: E501

        query_params = []
        if 'user_token' in params:
            query_params.append(('userToken', params['user_token']))  # noqa: E501
        if 'user_type' in params:
            query_params.append(('userType', params['user_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/hess/api/site/{siteId}/overview', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2002',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def hess_api_user_sites_list_get(self, user_token, page, size, **kwargs):  # noqa: E501
        """Site List  # noqa: E501

        Returns a list of sites related to the given token, which is the account api_key. This API accepts parameters for convenient search, sort and pagination.Limit: Only support to 2 searh text at once; Only support to 1 sort text at once  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.hess_api_user_sites_list_get(user_token, page, size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object page: The first site index to be returned in the results (required)
        :param object size: Pagesize of each page: - 5 - 10 - 30 (required)
        :param object user_type: User Type
        :param object power_station_type: Power Station Type: 1 - Grid-tied solar system 2 - Solar storage system 3 - EV charging hub 4 - EV charging hub with solar storage
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.hess_api_user_sites_list_get_with_http_info(user_token, page, size, **kwargs)  # noqa: E501
        else:
            (data) = self.hess_api_user_sites_list_get_with_http_info(user_token, page, size, **kwargs)  # noqa: E501
            return data

    def hess_api_user_sites_list_get_with_http_info(self, user_token, page, size, **kwargs):  # noqa: E501
        """Site List  # noqa: E501

        Returns a list of sites related to the given token, which is the account api_key. This API accepts parameters for convenient search, sort and pagination.Limit: Only support to 2 searh text at once; Only support to 1 sort text at once  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.hess_api_user_sites_list_get_with_http_info(user_token, page, size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object user_token: User token (required)
        :param object page: The first site index to be returned in the results (required)
        :param object size: Pagesize of each page: - 5 - 10 - 30 (required)
        :param object user_type: User Type
        :param object power_station_type: Power Station Type: 1 - Grid-tied solar system 2 - Solar storage system 3 - EV charging hub 4 - EV charging hub with solar storage
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_token', 'page', 'size', 'user_type', 'power_station_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hess_api_user_sites_list_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_token' is set
        if ('user_token' not in params or
                params['user_token'] is None):
            raise ValueError("Missing the required parameter `user_token` when calling `hess_api_user_sites_list_get`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `hess_api_user_sites_list_get`")  # noqa: E501
        # verify the required parameter 'size' is set
        if ('size' not in params or
                params['size'] is None):
            raise ValueError("Missing the required parameter `size` when calling `hess_api_user_sites_list_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'user_token' in params:
            query_params.append(('userToken', params['user_token']))  # noqa: E501
        if 'user_type' in params:
            query_params.append(('userType', params['user_type']))  # noqa: E501
        if 'power_station_type' in params:
            query_params.append(('powerStationType', params['power_station_type']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'size' in params:
            query_params.append(('size', params['size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/hess/api/userSites/list', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2001',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Livoltek API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DeviceDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'object',
        'inverter_sn': 'object',
        'collector_sn': 'object',
        'product_type': 'object',
        'firmware_version': 'object',
        'device_manufacturer': 'object',
        'device_type': 'object',
        'running_status': 'object',
        'update_time': 'object'
    }

    attribute_map = {
        'id': 'id',
        'inverter_sn': 'inverterSn',
        'collector_sn': 'collectorSn',
        'product_type': 'productType',
        'firmware_version': 'firmwareVersion',
        'device_manufacturer': 'deviceManufacturer',
        'device_type': 'deviceType',
        'running_status': 'runningStatus',
        'update_time': 'updateTime'
    }

    def __init__(self, id=None, inverter_sn=None, collector_sn=None, product_type=None, firmware_version=None, device_manufacturer=None, device_type=None, running_status=None, update_time=None):  # noqa: E501
        """DeviceDetails - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._inverter_sn = None
        self._collector_sn = None
        self._product_type = None
        self._firmware_version = None
        self._device_manufacturer = None
        self._device_type = None
        self._running_status = None
        self._update_time = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if inverter_sn is not None:
            self.inverter_sn = inverter_sn
        if collector_sn is not None:
            self.collector_sn = collector_sn
        if product_type is not None:
            self.product_type = product_type
        if firmware_version is not None:
            self.firmware_version = firmware_version
        if device_manufacturer is not None:
            self.device_manufacturer = device_manufacturer
        if device_type is not None:
            self.device_type = device_type
        if running_status is not None:
            self.running_status = running_status
        if update_time is not None:
            self.update_time = update_time

    @property
    def id(self):
        """Gets the id of this DeviceDetails.  # noqa: E501

        Device id  # noqa: E501

        :return: The id of this DeviceDetails.  # noqa: E501
        :rtype: object
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeviceDetails.

        Device id  # noqa: E501

        :param id: The id of this DeviceDetails.  # noqa: E501
        :type: object
        """

        self._id = id

    @property
    def inverter_sn(self):
        """Gets the inverter_sn of this DeviceDetails.  # noqa: E501

        Device SN  # noqa: E501

        :return: The inverter_sn of this DeviceDetails.  # noqa: E501
        :rtype: object
        """
        return self._inverter_sn

    @inverter_sn.setter
    def inverter_sn(self, inverter_sn):
        """Sets the inverter_sn of this DeviceDetails.

        Device SN  # noqa: E501

        :param inverter_sn: The inverter_sn of this DeviceDetails.  # noqa: E501
        :type: object
        """

        self._inverter_sn = inverter_sn

    @property
    def collector_sn(self):
        """Gets the collector_sn of this DeviceDetails.  # noqa: E501

        Device datalogger SN  # noqa: E501

        :return: The collector_sn of this DeviceDetails.  # noqa: E501
        :rtype: object
        """
        return self._collector_sn

    @collector_sn.setter
    def collector_sn(self, collector_sn):
        """Sets the collector_sn of this DeviceDetails.

        Device datalogger SN  # noqa: E501

        :param collector_sn: The collector_sn of this DeviceDetails.  # noqa: E501
        :type: object
        """

        self._collector_sn = collector_sn

    @property
    def product_type(self):
        """Gets the product_type of this DeviceDetails.  # noqa: E501

        Device type  # noqa: E501

        :return: The product_type of this DeviceDetails.  # noqa: E501
        :rtype: object
        """
        return self._product_type

    @product_type.setter
    def product_type(self, product_type):
        """Sets the product_type of this DeviceDetails.

        Device type  # noqa: E501

        :param product_type: The product_type of this DeviceDetails.  # noqa: E501
        :type: object
        """

        self._product_type = product_type

    @property
    def firmware_version(self):
        """Gets the firmware_version of this DeviceDetails.  # noqa: E501

        Device Manufacturer  # noqa: E501

        :return: The firmware_version of this DeviceDetails.  # noqa: E501
        :rtype: object
        """
        return self._firmware_version

    @firmware_version.setter
    def firmware_version(self, firmware_version):
        """Sets the firmware_version of this DeviceDetails.

        Device Manufacturer  # noqa: E501

        :param firmware_version: The firmware_version of this DeviceDetails.  # noqa: E501
        :type: object
        """

        self._firmware_version = firmware_version

    @property
    def device_manufacturer(self):
        """Gets the device_manufacturer of this DeviceDetails.  # noqa: E501

        Device Manufacturer  # noqa: E501

        :return: The device_manufacturer of this DeviceDetails.  # noqa: E501
        :rtype: object
        """
        return self._device_manufacturer

    @device_manufacturer.setter
    def device_manufacturer(self, device_manufacturer):
        """Sets the device_manufacturer of this DeviceDetails.

        Device Manufacturer  # noqa: E501

        :param device_manufacturer: The device_manufacturer of this DeviceDetails.  # noqa: E501
        :type: object
        """

        self._device_manufacturer = device_manufacturer

    @property
    def device_type(self):
        """Gets the device_type of this DeviceDetails.  # noqa: E501

        Device Type  # noqa: E501

        :return: The device_type of this DeviceDetails.  # noqa: E501
        :rtype: object
        """
        return self._device_type

    @device_type.setter
    def device_type(self, device_type):
        """Sets the device_type of this DeviceDetails.

        Device Type  # noqa: E501

        :param device_type: The device_type of this DeviceDetails.  # noqa: E501
        :type: object
        """

        self._device_type = device_type

    @property
    def running_status(self):
        """Gets the running_status of this DeviceDetails.  # noqa: E501

        Device running status  # noqa: E501

        :return: The running_status of this DeviceDetails.  # noqa: E501
        :rtype: object
        """
        return self._running_status

    @running_status.setter
    def running_status(self, running_status):
        """Sets the running_status of this DeviceDetails.

        Device running status  # noqa: E501

        :param running_status: The running_status of this DeviceDetails.  # noqa: E501
        :type: object
        """

        self._running_status = running_status

    @property
    def update_time(self):
        """Gets the update_time of this DeviceDetails.  # noqa: E501

        Latest update time (ms)  # noqa: E501

        :return: The update_time of this DeviceDetails.  # noqa: E501
        :rtype: object
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this DeviceDetails.

        Latest update time (ms)  # noqa: E501

        :param update_time: The update_time of this DeviceDetails.  # noqa: E501
        :type: object
        """

        self._update_time = update_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DeviceDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8
from setuptools import setup, find_packages  # noqa: H301

NAME = "pylivoltek"
VERSION = "1.0.8"
REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Livoltek API",
    author_email="",
    url="",
    keywords=["Swagger", "Livoltek API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    Python API Client for the Livoltek API
    """
)



# coding: utf-8

"""
    Livoltek API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pylivoltek
from pylivoltek.models.inline_response2005 import InlineResponse2005  # noqa: E501
from pylivoltek.rest import ApiException


class TestInlineResponse2005(unittest.TestCase):
    """InlineResponse2005 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInlineResponse2005(self):
        """Test InlineResponse2005"""
        # FIXME: construct object with mandatory attributes with example values
        # model = pylivoltek.models.inline_response2005.InlineResponse2005()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Livoltek API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GridImportExport(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'site_id': 'object',
        'ts': 'object',
        'positive': 'object',
        'negative': 'object'
    }

    attribute_map = {
        'site_id': 'siteId',
        'ts': 'ts',
        'positive': 'positive',
        'negative': 'negative'
    }

    def __init__(self, site_id=None, ts=None, positive=None, negative=None):  # noqa: E501
        """GridImportExport - a model defined in Swagger"""  # noqa: E501
        self._site_id = None
        self._ts = None
        self._positive = None
        self._negative = None
        self.discriminator = None
        if site_id is not None:
            self.site_id = site_id
        if ts is not None:
            self.ts = ts
        if positive is not None:
            self.positive = positive
        if negative is not None:
            self.negative = negative

    @property
    def site_id(self):
        """Gets the site_id of this GridImportExport.  # noqa: E501

        Site ID  # noqa: E501

        :return: The site_id of this GridImportExport.  # noqa: E501
        :rtype: object
        """
        return self._site_id

    @site_id.setter
    def site_id(self, site_id):
        """Sets the site_id of this GridImportExport.

        Site ID  # noqa: E501

        :param site_id: The site_id of this GridImportExport.  # noqa: E501
        :type: object
        """

        self._site_id = site_id

    @property
    def ts(self):
        """Gets the ts of this GridImportExport.  # noqa: E501

        Timestamp  # noqa: E501

        :return: The ts of this GridImportExport.  # noqa: E501
        :rtype: object
        """
        return self._ts

    @ts.setter
    def ts(self, ts):
        """Sets the ts of this GridImportExport.

        Timestamp  # noqa: E501

        :param ts: The ts of this GridImportExport.  # noqa: E501
        :type: object
        """

        self._ts = ts

    @property
    def positive(self):
        """Gets the positive of this GridImportExport.  # noqa: E501

        Grid Import  # noqa: E501

        :return: The positive of this GridImportExport.  # noqa: E501
        :rtype: object
        """
        return self._positive

    @positive.setter
    def positive(self, positive):
        """Sets the positive of this GridImportExport.

        Grid Import  # noqa: E501

        :param positive: The positive of this GridImportExport.  # noqa: E501
        :type: object
        """

        self._positive = positive

    @property
    def negative(self):
        """Gets the negative of this GridImportExport.  # noqa: E501

        Grid Export  # noqa: E501

        :return: The negative of this GridImportExport.  # noqa: E501
        :rtype: object
        """
        return self._negative

    @negative.setter
    def negative(self, negative):
        """Sets the negative of this GridImportExport.

        Grid Export  # noqa: E501

        :param negative: The negative of this GridImportExport.  # noqa: E501
        :type: object
        """

        self._negative = negative

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GridImportExport, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GridImportExport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
